# SKA Utils

Набор утилит, которые помогают мне и команде в которой я работаю, выполнять рабочие задачи

## exehelper
Проверяет совпадает ли версия в toml-файле на сетевом диске и в классе ```CheckExeVersion```

Библиотека позволяет проверить соответствие версии текущего файла и версии в файле .toml, лежащего на сетевом диске

file.toml
```toml
file_name="version"
```

file_name — название программы, должно быть единым в файле toml и при инициализации класса ```CheckExeVersion```

Пример использования можно увидеть в папке ```tests``` репозитория github
